@@ -1,7 +1,6 @@
 from sqlglot import expressions as exp
 from sqlglot.optimizer.normalize import normalized
 from sqlglot.optimizer.scope import Scope, traverse_scope
-from sqlglot.optimizer.simplify import simplify
 
 
 def eliminate_joins(expression):
@@ -33,7 +32,7 @@ def eliminate_joins(expression):
 
         # Reverse the joins so we can remove chains of unused joins
         for join in reversed(joins):
-            alias = join.this.alias_or_name
+            alias = join.alias_or_name
             if _should_eliminate_join(scope, join, alias):
                 join.pop()
                 scope.remove_source(alias)
@@ -127,7 +126,7 @@ def join_condition(join):
         tuple[list[str], list[str], exp.Expression]:
             Tuple of (source key, join key, remaining predicate)
     """
-    name = join.this.alias_or_name
+    name = join.alias_or_name
     on = (join.args.get("on") or exp.true()).copy()
     source_key = []
     join_key = []
@@ -154,7 +153,7 @@ def join_condition(join):
     #
     # should pull y.b as the join key and x.a as the source key
     if normalized(on):
-        on = on if isinstance(on, exp.And) else exp.and_(on, exp.true())
+        on = on if isinstance(on, exp.And) else exp.and_(on, exp.true(), copy=False)
 
         for condition in on.flatten():
             if isinstance(condition, exp.EQ):
@@ -179,6 +178,4 @@ def join_condition(join):
         for condition in conditions:
             extract_condition(condition)
 
-    on = simplify(on)
-    remaining_condition = None if on == exp.true() else on
-    return source_key, join_key, remaining_condition
+    return source_key, join_key, on
