@@ -10,10 +10,10 @@ def pushdown_predicates(expression):
 
     Example:
         >>> import sqlglot
-        >>> sql = "SELECT * FROM (SELECT * FROM x AS x) AS y WHERE y.a = 1"
+        >>> sql = "SELECT y.a AS a FROM (SELECT x.a AS a FROM x AS x) AS y WHERE y.a = 1"
         >>> expression = sqlglot.parse_one(sql)
         >>> pushdown_predicates(expression).sql()
-        'SELECT * FROM (SELECT * FROM x AS x WHERE y.a = 1) AS y WHERE TRUE'
+        'SELECT y.a AS a FROM (SELECT x.a AS a FROM x AS x WHERE x.a = 1) AS y WHERE TRUE'
 
     Args:
         expression (sqlglot.Expression): expression to optimize
@@ -21,26 +21,28 @@ def pushdown_predicates(expression):
         sqlglot.Expression: optimized expression
     """
     root = build_scope(expression)
-    scope_ref_count = root.ref_count()
 
-    for scope in reversed(list(root.traverse())):
-        select = scope.expression
-        where = select.args.get("where")
-        if where:
-            selected_sources = scope.selected_sources
-            # a right join can only push down to itself and not the source FROM table
-            for k, (node, source) in selected_sources.items():
-                parent = node.find_ancestor(exp.Join, exp.From)
-                if isinstance(parent, exp.Join) and parent.side == "RIGHT":
-                    selected_sources = {k: (node, source)}
-                    break
-            pushdown(where.this, selected_sources, scope_ref_count)
+    if root:
+        scope_ref_count = root.ref_count()
 
-        # joins should only pushdown into itself, not to other joins
-        # so we limit the selected sources to only itself
-        for join in select.args.get("joins") or []:
-            name = join.this.alias_or_name
-            pushdown(join.args.get("on"), {name: scope.selected_sources[name]}, scope_ref_count)
+        for scope in reversed(list(root.traverse())):
+            select = scope.expression
+            where = select.args.get("where")
+            if where:
+                selected_sources = scope.selected_sources
+                # a right join can only push down to itself and not the source FROM table
+                for k, (node, source) in selected_sources.items():
+                    parent = node.find_ancestor(exp.Join, exp.From)
+                    if isinstance(parent, exp.Join) and parent.side == "RIGHT":
+                        selected_sources = {k: (node, source)}
+                        break
+                pushdown(where.this, selected_sources, scope_ref_count)
+
+            # joins should only pushdown into itself, not to other joins
+            # so we limit the selected sources to only itself
+            for join in select.args.get("joins") or []:
+                name = join.alias_or_name
+                pushdown(join.args.get("on"), {name: scope.selected_sources[name]}, scope_ref_count)
 
     return expression
 
@@ -91,10 +93,10 @@ def pushdown_dnf(predicates, scope, scope_ref_count):
     pushdown_tables = set()
 
     for a in predicates:
-        a_tables = set(exp.column_table_names(a))
+        a_tables = exp.column_table_names(a)
 
         for b in predicates:
-            a_tables &= set(exp.column_table_names(b))
+            a_tables &= exp.column_table_names(b)
 
         pushdown_tables.update(a_tables)
 
@@ -145,7 +147,7 @@ def nodes_for_predicate(predicate, sources, scope_ref_count):
     tables = exp.column_table_names(predicate)
     where_condition = isinstance(predicate.find_ancestor(exp.Join, exp.Where), exp.Where)
 
-    for table in tables:
+    for table in sorted(tables):
         node, source = sources.get(table) or (None, None)
 
         # if the predicate is in a where statement we can try to push it down
