@@ -70,8 +70,8 @@ class TestHive(Validator):
         self.validate_all(
             "1s",
             write={
-                "duckdb": "CAST(1 AS SMALLINT)",
-                "presto": "CAST(1 AS SMALLINT)",
+                "duckdb": "TRY_CAST(1 AS SMALLINT)",
+                "presto": "TRY_CAST(1 AS SMALLINT)",
                 "hive": "CAST(1 AS SMALLINT)",
                 "spark": "CAST(1 AS SHORT)",
             },
@@ -79,8 +79,8 @@ class TestHive(Validator):
         self.validate_all(
             "1S",
             write={
-                "duckdb": "CAST(1 AS SMALLINT)",
-                "presto": "CAST(1 AS SMALLINT)",
+                "duckdb": "TRY_CAST(1 AS SMALLINT)",
+                "presto": "TRY_CAST(1 AS SMALLINT)",
                 "hive": "CAST(1 AS SMALLINT)",
                 "spark": "CAST(1 AS SHORT)",
             },
@@ -88,8 +88,8 @@ class TestHive(Validator):
         self.validate_all(
             "1Y",
             write={
-                "duckdb": "CAST(1 AS TINYINT)",
-                "presto": "CAST(1 AS TINYINT)",
+                "duckdb": "TRY_CAST(1 AS TINYINT)",
+                "presto": "TRY_CAST(1 AS TINYINT)",
                 "hive": "CAST(1 AS TINYINT)",
                 "spark": "CAST(1 AS BYTE)",
             },
@@ -97,8 +97,8 @@ class TestHive(Validator):
         self.validate_all(
             "1L",
             write={
-                "duckdb": "CAST(1 AS BIGINT)",
-                "presto": "CAST(1 AS BIGINT)",
+                "duckdb": "TRY_CAST(1 AS BIGINT)",
+                "presto": "TRY_CAST(1 AS BIGINT)",
                 "hive": "CAST(1 AS BIGINT)",
                 "spark": "CAST(1 AS LONG)",
             },
@@ -106,8 +106,8 @@ class TestHive(Validator):
         self.validate_all(
             "1.0bd",
             write={
-                "duckdb": "CAST(1.0 AS DECIMAL)",
-                "presto": "CAST(1.0 AS DECIMAL)",
+                "duckdb": "TRY_CAST(1.0 AS DECIMAL)",
+                "presto": "TRY_CAST(1.0 AS DECIMAL)",
                 "hive": "CAST(1.0 AS DECIMAL)",
                 "spark": "CAST(1.0 AS DECIMAL)",
             },
@@ -148,6 +148,9 @@ class TestHive(Validator):
         self.validate_identity(
             """CREATE EXTERNAL TABLE x (y INT) ROW FORMAT SERDE 'serde' ROW FORMAT DELIMITED FIELDS TERMINATED BY '1' WITH SERDEPROPERTIES ('input.regex'='')""",
         )
+        self.validate_identity(
+            """CREATE EXTERNAL TABLE `my_table` (`a7` ARRAY<DATE>) ROW FORMAT SERDE 'a' STORED AS INPUTFORMAT 'b' OUTPUTFORMAT 'c' LOCATION 'd' TBLPROPERTIES ('e'='f')"""
+        )
 
     def test_lateral_view(self):
         self.validate_all(
@@ -214,11 +217,11 @@ class TestHive(Validator):
         self.validate_all(
             "'\\\\a'",
             read={
-                "presto": "'\\a'",
+                "presto": "'\\\\a'",
             },
             write={
-                "duckdb": "'\\a'",
-                "presto": "'\\a'",
+                "duckdb": "'\\\\a'",
+                "presto": "'\\\\a'",
                 "hive": "'\\\\a'",
                 "spark": "'\\\\a'",
             },
@@ -246,11 +249,35 @@ class TestHive(Validator):
         )
 
     def test_time(self):
+        self.validate_all(
+            "(UNIX_TIMESTAMP(y) - UNIX_TIMESTAMP(x)) * 1000",
+            read={
+                "presto": "DATE_DIFF('millisecond', x, y)",
+            },
+        )
+        self.validate_all(
+            "UNIX_TIMESTAMP(y) - UNIX_TIMESTAMP(x)",
+            read={
+                "presto": "DATE_DIFF('second', x, y)",
+            },
+        )
+        self.validate_all(
+            "(UNIX_TIMESTAMP(y) - UNIX_TIMESTAMP(x)) / 60",
+            read={
+                "presto": "DATE_DIFF('minute', x, y)",
+            },
+        )
+        self.validate_all(
+            "(UNIX_TIMESTAMP(y) - UNIX_TIMESTAMP(x)) / 3600",
+            read={
+                "presto": "DATE_DIFF('hour', x, y)",
+            },
+        )
         self.validate_all(
             "DATEDIFF(a, b)",
             write={
                 "duckdb": "DATE_DIFF('day', CAST(b AS DATE), CAST(a AS DATE))",
-                "presto": "DATE_DIFF('day', CAST(SUBSTR(CAST(b AS VARCHAR), 1, 10) AS DATE), CAST(SUBSTR(CAST(a AS VARCHAR), 1, 10) AS DATE))",
+                "presto": "DATE_DIFF('day', CAST(CAST(b AS TIMESTAMP) AS DATE), CAST(CAST(a AS TIMESTAMP) AS DATE))",
                 "hive": "DATEDIFF(TO_DATE(a), TO_DATE(b))",
                 "spark": "DATEDIFF(TO_DATE(a), TO_DATE(b))",
                 "": "DATEDIFF(TS_OR_DS_TO_DATE(a), TS_OR_DS_TO_DATE(b))",
@@ -278,7 +305,7 @@ class TestHive(Validator):
             "DATE_ADD('2020-01-01', 1)",
             write={
                 "duckdb": "CAST('2020-01-01' AS DATE) + INTERVAL 1 DAY",
-                "presto": "DATE_ADD('DAY', 1, DATE_PARSE(SUBSTR('2020-01-01', 1, 10), '%Y-%m-%d'))",
+                "presto": "DATE_ADD('DAY', 1, CAST(CAST('2020-01-01' AS TIMESTAMP) AS DATE))",
                 "hive": "DATE_ADD('2020-01-01', 1)",
                 "spark": "DATE_ADD('2020-01-01', 1)",
                 "": "TS_OR_DS_ADD('2020-01-01', 1, 'DAY')",
@@ -287,18 +314,23 @@ class TestHive(Validator):
         self.validate_all(
             "DATE_SUB('2020-01-01', 1)",
             write={
-                "duckdb": "CAST('2020-01-01' AS DATE) + INTERVAL 1 * -1 DAY",
-                "presto": "DATE_ADD('DAY', 1 * -1, DATE_PARSE(SUBSTR('2020-01-01', 1, 10), '%Y-%m-%d'))",
+                "duckdb": "CAST('2020-01-01' AS DATE) + INTERVAL (1 * -1) DAY",
+                "presto": "DATE_ADD('DAY', 1 * -1, CAST(CAST('2020-01-01' AS TIMESTAMP) AS DATE))",
                 "hive": "DATE_ADD('2020-01-01', 1 * -1)",
                 "spark": "DATE_ADD('2020-01-01', 1 * -1)",
                 "": "TS_OR_DS_ADD('2020-01-01', 1 * -1, 'DAY')",
             },
         )
+        self.validate_all("DATE_ADD('2020-01-01', -1)", read={"": "DATE_SUB('2020-01-01', 1)"})
+        self.validate_all("DATE_ADD(a, b * -1)", read={"": "DATE_SUB(a, b)"})
+        self.validate_all(
+            "ADD_MONTHS('2020-01-01', -2)", read={"": "DATE_SUB('2020-01-01', 2, month)"}
+        )
         self.validate_all(
             "DATEDIFF(TO_DATE(y), x)",
             write={
                 "duckdb": "DATE_DIFF('day', CAST(x AS DATE), CAST(CAST(y AS DATE) AS DATE))",
-                "presto": "DATE_DIFF('day', CAST(SUBSTR(CAST(x AS VARCHAR), 1, 10) AS DATE), CAST(SUBSTR(CAST(CAST(SUBSTR(CAST(y AS VARCHAR), 1, 10) AS DATE) AS VARCHAR), 1, 10) AS DATE))",
+                "presto": "DATE_DIFF('day', CAST(CAST(x AS TIMESTAMP) AS DATE), CAST(CAST(CAST(CAST(y AS TIMESTAMP) AS DATE) AS TIMESTAMP) AS DATE))",
                 "hive": "DATEDIFF(TO_DATE(TO_DATE(y)), TO_DATE(x))",
                 "spark": "DATEDIFF(TO_DATE(TO_DATE(y)), TO_DATE(x))",
                 "": "DATEDIFF(TS_OR_DS_TO_DATE(TS_OR_DS_TO_DATE(y)), TS_OR_DS_TO_DATE(x))",
@@ -320,7 +352,7 @@ class TestHive(Validator):
                 f"{unit}(x)",
                 write={
                     "duckdb": f"{unit}(CAST(x AS DATE))",
-                    "presto": f"{unit}(CAST(SUBSTR(CAST(x AS VARCHAR), 1, 10) AS DATE))",
+                    "presto": f"{unit}(CAST(CAST(x AS TIMESTAMP) AS DATE))",
                     "hive": f"{unit}(TO_DATE(x))",
                     "spark": f"{unit}(TO_DATE(x))",
                 },
@@ -330,7 +362,7 @@ class TestHive(Validator):
         self.validate_all(
             "SELECT fname, lname, age FROM person ORDER BY age DESC NULLS FIRST, fname ASC NULLS LAST, lname",
             write={
-                "duckdb": "SELECT fname, lname, age FROM person ORDER BY age DESC NULLS FIRST, fname NULLS LAST, lname",
+                "duckdb": "SELECT fname, lname, age FROM person ORDER BY age DESC NULLS FIRST, fname, lname NULLS FIRST",
                 "presto": "SELECT fname, lname, age FROM person ORDER BY age DESC NULLS FIRST, fname, lname NULLS FIRST",
                 "hive": "SELECT fname, lname, age FROM person ORDER BY age DESC NULLS FIRST, fname NULLS LAST, lname",
                 "spark": "SELECT fname, lname, age FROM person ORDER BY age DESC NULLS FIRST, fname NULLS LAST, lname",
@@ -338,6 +370,16 @@ class TestHive(Validator):
         )
 
     def test_hive(self):
+        self.validate_identity("SELECT * FROM test DISTRIBUTE BY y SORT BY x DESC ORDER BY l")
+        self.validate_identity(
+            "SELECT * FROM test WHERE RAND() <= 0.1 DISTRIBUTE BY RAND() SORT BY RAND()"
+        )
+        self.validate_identity("(SELECT 1 UNION SELECT 2) DISTRIBUTE BY z")
+        self.validate_identity("(SELECT 1 UNION SELECT 2) DISTRIBUTE BY z SORT BY x")
+        self.validate_identity("(SELECT 1 UNION SELECT 2) CLUSTER BY y DESC")
+        self.validate_identity("SELECT * FROM test CLUSTER BY y")
+
+        self.validate_identity("(SELECT 1 UNION SELECT 2) SORT BY z")
         self.validate_identity(
             "INSERT OVERWRITE TABLE zipcodes PARTITION(state = '0') VALUES (896, 'US', 'TAMPA', 33607)"
         )
@@ -345,13 +387,13 @@ class TestHive(Validator):
             "INSERT OVERWRITE TABLE zipcodes PARTITION(state = 0) VALUES (896, 'US', 'TAMPA', 33607)"
         )
         self.validate_identity(
-            "SELECT a, b, SUM(c) FROM tabl AS t GROUP BY a, b GROUPING SETS ((a, b), a)"
+            "SELECT a, b, SUM(c) FROM tabl AS t GROUP BY a, b, GROUPING SETS ((a, b), a)"
         )
         self.validate_identity(
-            "SELECT a, b, SUM(c) FROM tabl AS t GROUP BY a, b GROUPING SETS ((t.a, b), a)"
+            "SELECT a, b, SUM(c) FROM tabl AS t GROUP BY a, b, GROUPING SETS ((t.a, b), a)"
         )
         self.validate_identity(
-            "SELECT a, b, SUM(c) FROM tabl AS t GROUP BY a, FOO(b) GROUPING SETS ((a, FOO(b)), a)"
+            "SELECT a, b, SUM(c) FROM tabl AS t GROUP BY a, FOO(b), GROUPING SETS ((a, FOO(b)), a)"
         )
         self.validate_identity(
             "SELECT key, value, GROUPING__ID, COUNT(*) FROM T1 GROUP BY key, value WITH CUBE"
@@ -369,6 +411,7 @@ class TestHive(Validator):
             "SELECT 1_a AS a FROM test_table",
             write={
                 "spark": "SELECT 1_a AS a FROM test_table",
+                "trino": 'SELECT "1_a" AS a FROM test_table',
             },
         )
         self.validate_all(
@@ -480,11 +523,10 @@ class TestHive(Validator):
             },
         )
         self.validate_all(
-            "SELECT * FROM x TABLESAMPLE(10) y",
+            "SELECT * FROM x.z TABLESAMPLE(10 PERCENT) y",
             write={
-                "presto": "SELECT * FROM x AS y TABLESAMPLE(10)",
-                "hive": "SELECT * FROM x TABLESAMPLE(10) AS y",
-                "spark": "SELECT * FROM x TABLESAMPLE(10) AS y",
+                "hive": "SELECT * FROM x.z TABLESAMPLE (10 PERCENT) AS y",
+                "spark": "SELECT * FROM x.z TABLESAMPLE (10 PERCENT) AS y",
             },
         )
         self.validate_all(
@@ -517,6 +559,12 @@ class TestHive(Validator):
                 "spark": "GET_JSON_OBJECT(x, '$.name')",
             },
         )
+        self.validate_all(
+            "STRUCT(a = b, c = d)",
+            read={
+                "snowflake": "OBJECT_CONSTRUCT(a, b, c, d)",
+            },
+        )
         self.validate_all(
             "MAP(a, b, c, d)",
             read={
@@ -526,7 +574,6 @@ class TestHive(Validator):
                 "hive": "MAP(a, b, c, d)",
                 "presto": "MAP(ARRAY[a, c], ARRAY[b, d])",
                 "spark": "MAP(a, b, c, d)",
-                "snowflake": "OBJECT_CONSTRUCT(a, b, c, d)",
             },
             write={
                 "": "MAP(ARRAY(a, c), ARRAY(b, d))",
@@ -596,7 +643,7 @@ class TestHive(Validator):
         self.validate_all(
             "x div y",
             write={
-                "duckdb": "CAST(x / y AS INT)",
+                "duckdb": "x // y",
                 "presto": "CAST(x / y AS INTEGER)",
                 "hive": "CAST(x / y AS INT)",
                 "spark": "CAST(x / y AS INT)",
@@ -626,30 +673,38 @@ class TestHive(Validator):
             },
         )
         self.validate_all(
-            "SELECT * FROM x TABLESAMPLE(1) AS foo",
+            "SELECT * FROM x TABLESAMPLE (1 PERCENT) AS foo",
             read={
-                "presto": "SELECT * FROM x AS foo TABLESAMPLE(1)",
+                "presto": "SELECT * FROM x AS foo TABLESAMPLE BERNOULLI (1)",
             },
             write={
-                "presto": "SELECT * FROM x AS foo TABLESAMPLE(1)",
-                "hive": "SELECT * FROM x TABLESAMPLE(1) AS foo",
-                "spark": "SELECT * FROM x TABLESAMPLE(1) AS foo",
+                "hive": "SELECT * FROM x TABLESAMPLE (1 PERCENT) AS foo",
+                "spark": "SELECT * FROM x TABLESAMPLE (1 PERCENT) AS foo",
             },
         )
         self.validate_all(
-            "SELECT * FROM x TABLESAMPLE(1) AS foo",
-            read={
-                "presto": "SELECT * FROM x AS foo TABLESAMPLE(1)",
-            },
+            "SELECT a, SUM(c) FROM t GROUP BY a, DATE_FORMAT(b, 'yyyy'), GROUPING SETS ((a, DATE_FORMAT(b, 'yyyy')), a)",
             write={
-                "presto": "SELECT * FROM x AS foo TABLESAMPLE(1)",
-                "hive": "SELECT * FROM x TABLESAMPLE(1) AS foo",
-                "spark": "SELECT * FROM x TABLESAMPLE(1) AS foo",
+                "hive": "SELECT a, SUM(c) FROM t GROUP BY a, DATE_FORMAT(CAST(b AS TIMESTAMP), 'yyyy'), GROUPING SETS ((a, DATE_FORMAT(CAST(b AS TIMESTAMP), 'yyyy')), a)",
             },
         )
+
+    def test_escapes(self) -> None:
+        self.validate_identity("'\n'")
+        self.validate_identity("'\\n'")
+        self.validate_identity("'\\\n'")
+        self.validate_identity("'\\\\n'")
+        self.validate_identity("''")
+        self.validate_identity("'\\\\'")
+        self.validate_identity("'\z'")
+        self.validate_identity("'\\z'")
+        self.validate_identity("'\\\z'")
+        self.validate_identity("'\\\\z'")
+
+    def test_data_type(self):
         self.validate_all(
-            "SELECT a, SUM(c) FROM t GROUP BY a, DATE_FORMAT(b, 'yyyy') GROUPING SETS ((a, DATE_FORMAT(b, 'yyyy')), a)",
+            "CAST(a AS BIT)",
             write={
-                "hive": "SELECT a, SUM(c) FROM t GROUP BY a, DATE_FORMAT(CAST(b AS TIMESTAMP), 'yyyy') GROUPING SETS ((a, DATE_FORMAT(CAST(b AS TIMESTAMP), 'yyyy')), a)",
+                "hive": "CAST(a AS BOOLEAN)",
             },
         )
