@@ -1,7 +1,11 @@
 SUM(1)
 SUM(CASE WHEN x > 1 THEN 1 ELSE 0 END) / y
 1
+(1)
+1.
+(1.)
 1.0
+(1.0)
 1E2
 1E+2
 1E-2
@@ -69,6 +73,8 @@ a.B()
 a['x'].C()
 int.x
 map.x
+SELECT update
+SELECT x.update
 SELECT call.x
 a.b.INT(1.234)
 INT(x / 100)
@@ -155,6 +161,7 @@ DATE(x) = DATE(y)
 TIMESTAMP(DATE(x))
 TIMESTAMP_TRUNC(COALESCE(time_field, CURRENT_TIMESTAMP()), DAY)
 COUNT(DISTINCT CASE WHEN DATE_TRUNC(DATE(time_field), isoweek) = DATE_TRUNC(DATE(time_field2), isoweek) THEN report_id ELSE NULL END)
+COUNT(a, b)
 x[y - 1]
 CASE WHEN SUM(x) > 3 THEN 1 END OVER (PARTITION BY x)
 SUM(ROW() OVER (PARTITION BY x))
@@ -224,6 +231,7 @@ SELECT SUM(x IGNORE NULLS) AS x
 SELECT COUNT(x RESPECT NULLS)
 SELECT TRUNCATE(a, b)
 SELECT ARRAY_AGG(DISTINCT x IGNORE NULLS ORDER BY a, b DESC LIMIT 10) AS x
+SELECT ARRAY_AGG(DISTINCT x IGNORE NULLS ORDER BY a, b DESC LIMIT 1, 10) AS x
 SELECT ARRAY_AGG(STRUCT(x, x AS y) ORDER BY z DESC) AS x
 SELECT LAST_VALUE(x IGNORE NULLS) OVER y AS x
 SELECT LAG(x) OVER (ORDER BY y) AS x
@@ -511,8 +519,6 @@ SELECT student, score FROM tests CROSS JOIN UNNEST(scores) AS t(a, b)
 SELECT student, score FROM tests CROSS JOIN UNNEST(scores) WITH ORDINALITY AS t(a, b)
 SELECT student, score FROM tests CROSS JOIN UNNEST(x.scores) AS t(score)
 SELECT student, score FROM tests CROSS JOIN UNNEST(ARRAY(x.scores)) AS t(score)
-SELECT * FROM t WITH (TABLOCK, INDEX(myindex))
-SELECT * FROM t WITH (NOWAIT)
 CREATE TABLE foo AS (SELECT 1) UNION ALL (SELECT 2)
 CREATE TABLE foo (id INT PRIMARY KEY ASC)
 CREATE TABLE a.b AS SELECT 1
@@ -601,6 +607,7 @@ CREATE FUNCTION a.b.c()
 CREATE INDEX abc ON t (a)
 CREATE INDEX abc ON t (a, b, b)
 CREATE INDEX abc ON t (a NULLS LAST)
+CREATE INDEX pointloc ON points USING GIST(BOX(location, location))
 CREATE UNIQUE INDEX abc ON t (a, b, b)
 CREATE UNIQUE INDEX IF NOT EXISTS my_idx ON tbl (a, b)
 CREATE SCHEMA x
@@ -671,6 +678,7 @@ INSERT INTO x VALUES (1, 'a', 2.0), (1, 'a', 3.0), (X(), y[1], z.x)
 INSERT INTO y (a, b, c) SELECT a, b, c FROM x
 INSERT INTO y (SELECT 1) UNION (SELECT 2)
 INSERT INTO result_table (WITH test AS (SELECT * FROM source_table) SELECT * FROM test)
+INSERT INTO "tests_user" ("username", "first_name", "last_name") VALUES ('fiara', 'Fiara', 'Ironhide') RETURNING "tests_user"."id"
 INSERT OVERWRITE TABLE x IF EXISTS SELECT * FROM y
 INSERT OVERWRITE TABLE a.b IF EXISTS SELECT * FROM y
 INSERT OVERWRITE DIRECTORY 'x' SELECT 1
@@ -805,6 +813,7 @@ PRAGMA schema.synchronous = 2
 PRAGMA schema.synchronous = FULL
 PRAGMA schema.memory_limit = '1GB'
 JSON_OBJECT()
+JSON_OBJECT(*)
 JSON_OBJECT('key1': 1, 'key2': TRUE)
 JSON_OBJECT('id': '5', 'fld1': 'bla', 'fld2': 'bar')
 JSON_OBJECT('x': NULL, 'y': 1 NULL ON NULL)
@@ -820,3 +829,7 @@ SELECT PERCENTILE_CONT(x, 0.5 RESPECT NULLS) OVER ()
 SELECT PERCENTILE_CONT(x, 0.5 IGNORE NULLS) OVER ()
 WITH my_cte AS (SELECT 'a' AS desc) SELECT desc AS description FROM my_cte
 WITH my_cte AS (SELECT 'a' AS asc) SELECT asc AS description FROM my_cte
+SELECT * FROM case
+SELECT * FROM schema.case
+SELECT * FROM current_date
+SELECT * FROM schema.current_date
